@@ -2,14 +2,14 @@ from django.contrib import auth
 from django.dispatch import Signal
 from django.contrib.sites.models import Site
 
-from urlauth.signals import key_user_found
+from urlauth.signals import authkey_processed
 from urlauth.models import AuthKey
 
 from account.util import email_template
 
 account_created = Signal(providing_args=['user', 'request'])
 
-def key_user_found_handler(key, user, **kwargs):
+def authkey_handler(key, user, **kwargs):
     extra = key.extra
     action = extra.get('action')
 
@@ -27,4 +27,4 @@ def key_user_found_handler(key, user, **kwargs):
                 user.save()
 
 
-key_user_found.connect(key_user_found_handler, sender=AuthKey)
+authkey_processed.connect(authkey_handler, sender=AuthKey)
